document.addEventListener('DOMContentLoaded', () => {
    // Menu Toggle
    const menuToggle = document.querySelector('.menu-toggle');
    const navLinks = document.querySelector('.nav-links');
    
    menuToggle.addEventListener('click', () => {
        navLinks.classList.toggle('active');
    });

    // Modal Functionality
    const modal = document.getElementById('modal');
    const modalContent = document.getElementById('modalContent');
    const closeBtn = document.querySelector('.close');

    function showModal(content) {
        modalContent.innerHTML = content;
        modal.style.display = 'block';
    }

    closeBtn.onclick = () => {
        modal.style.display = 'none';
    }

    window.onclick = (e) => {
        if (e.target === modal) {
            modal.style.display = 'none';
        }
    }

    // Habits Management
    const addHabitBtn = document.getElementById('addHabitBtn');
    const habitsContainer = document.getElementById('habitsContainer');

    addHabitBtn.addEventListener('click', () => {
        const habitForm = `
            <form id="habitForm">
                <h3>Add New Habit</h3>
                <input type="text" placeholder="Habit Name" required>
                <select required>
                    <option value="daily">Daily</option>
                    <option value="weekly">Weekly</option>
                    <option value="monthly">Monthly</option>
                </select>
                <button type="submit">Add Habit</button>
            </form>
        `;
        showModal(habitForm);
    });

    // Countdown Timer
    const setCountdownBtn = document.getElementById('setCountdownBtn');
    let countdownInterval;

    setCountdownBtn.addEventListener('click', () => {
        const dateForm = `
            <form id="dateForm">
                <h3>Set Target Date</h3>
                <input type="datetime-local" required>
                <button type="submit">Start Countdown</button>
            </form>
        `;
        showModal(dateForm);
    });

    function updateCountdown(targetDate) {
        clearInterval(countdownInterval);
        
        countdownInterval = setInterval(() => {
            const now = new Date().getTime();
            const distance = targetDate - now;

            const days = Math.floor(distance / (1000 * 60 * 60 * 24));
            const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
            const seconds = Math.floor((distance % (1000 * 60)) / 1000);

            document.getElementById('days').textContent = days.toString().padStart(2, '0');
            document.getElementById('hours').textContent = hours.toString().padStart(2, '0');
            document.getElementById('minutes').textContent = minutes.toString().padStart(2, '0');
            document.getElementById('seconds').textContent = seconds.toString().padStart(2, '0');

            if (distance < 0) {
                clearInterval(countdownInterval);
                document.getElementById('countdownDisplay').textContent = "EXPIRED";
            }
        }, 1000);
    }

    // Local Storage Management
    function saveData(key, data) {
        localStorage.setItem(key, JSON.stringify(data));
    }

    function loadData(key) {
        const data = localStorage.getItem(key);
        return data ? JSON.parse(data) : null;
    }
});
